@@ -70,17 +70,17 @@
 <context>
     <name>AlarmPickSelector</name>
     <message>
-        <location filename="../AlarmPickSelector.cpp" line="142"/>
+        <location filename="../AlarmPickSelector.cpp" line="152"/>
         <source>None</source>
         <translation>Geen</translation>
     </message>
     <message>
-        <location filename="../AlarmPickSelector.cpp" line="154"/>
+        <location filename="../AlarmPickSelector.cpp" line="164"/>
         <source>Exact</source>
         <translation>Exact</translation>
     </message>
     <message numerus="yes">
-        <location filename="../AlarmPickSelector.cpp" line="156"/>
+        <location filename="../AlarmPickSelector.cpp" line="166"/>
         <source>%n hour(s) before</source>
         <translation>
             <numerusform>%n uur voor</numerusform>
@@ -88,7 +88,7 @@
         </translation>
     </message>
     <message numerus="yes">
-        <location filename="../AlarmPickSelector.cpp" line="157"/>
+        <location filename="../AlarmPickSelector.cpp" line="167"/>
         <source>%n minute(s) before</source>
         <translation>
             <numerusform>%n minuut voor</numerusform>
@@ -96,7 +96,7 @@
         </translation>
     </message>
     <message numerus="yes">
-        <location filename="../AlarmPickSelector.cpp" line="158"/>
+        <location filename="../AlarmPickSelector.cpp" line="168"/>
         <source>%n second(s) before</source>
         <translation>
             <numerusform>%n seconde voor</numerusform>
@@ -104,7 +104,7 @@
         </translation>
     </message>
     <message>
-        <location filename="../AlarmPickSelector.cpp" line="160"/>
+        <location filename="../AlarmPickSelector.cpp" line="170"/>
         <source>%1:%2:%3 before</source>
         <translation>%1:%2:%3 voor</translation>
     </message>
@@ -277,6 +277,29 @@
         </translation>
     </message>
 </context>
+<context>
+    <name>ChangeManager</name>
+    <message>
+        <location filename="../ChangeManager.cpp" line="239"/>
+        <source>Delete event?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ChangeManager.cpp" line="242"/>
+        <source>Delete task?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ChangeManager.cpp" line="245"/>
+        <source>Delete note?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ChangeManager.cpp" line="248"/>
+        <source>Delete component?</source>
+        <translation>Onderdeel verwijderen?</translation>
+    </message>
+</context>
 <context>
     <name>ColorPickDialog</name>
     <message>
@@ -315,17 +338,17 @@ day</source>
 <context>
     <name>ComponentListWidget</name>
     <message>
-        <location filename="../ComponentListWidget.cpp" line="72"/>
+        <location filename="../ComponentListWidget.cpp" line="71"/>
         <source>Edit</source>
         <translation>Bewerken</translation>
     </message>
     <message>
-        <location filename="../ComponentListWidget.cpp" line="73"/>
+        <location filename="../ComponentListWidget.cpp" line="72"/>
         <source>Clone</source>
         <translation>Kloon</translation>
     </message>
     <message>
-        <location filename="../ComponentListWidget.cpp" line="74"/>
+        <location filename="../ComponentListWidget.cpp" line="73"/>
         <source>Delete</source>
         <translation>Verwijderen</translation>
     </message>
@@ -333,17 +356,17 @@ day</source>
 <context>
     <name>ComponentWidget</name>
     <message>
-        <location filename="../week/ComponentWidget.cpp" line="181"/>
+        <location filename="../week/ComponentWidget.cpp" line="183"/>
         <source>Edit</source>
         <translation>Bewerken</translation>
     </message>
     <message>
-        <location filename="../week/ComponentWidget.cpp" line="182"/>
+        <location filename="../week/ComponentWidget.cpp" line="184"/>
         <source>Clone</source>
         <translation>Kloon</translation>
     </message>
     <message>
-        <location filename="../week/ComponentWidget.cpp" line="183"/>
+        <location filename="../week/ComponentWidget.cpp" line="185"/>
         <source>Delete</source>
         <translation>Verwijder</translation>
     </message>
@@ -496,31 +519,36 @@ day</source>
     </message>
     <message>
         <location filename="../EventEditDialog.ui" line="118"/>
+        <source>Time zone</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../EventEditDialog.ui" line="125"/>
         <source>Repeat</source>
         <translation>Herhaal</translation>
     </message>
     <message>
-        <location filename="../EventEditDialog.ui" line="128"/>
+        <location filename="../EventEditDialog.ui" line="135"/>
         <source>Calendar</source>
         <translation>Kalender</translation>
     </message>
     <message>
-        <location filename="../EventEditDialog.ui" line="135"/>
+        <location filename="../EventEditDialog.ui" line="142"/>
         <source>Alarm</source>
         <translation>Alarm</translation>
     </message>
     <message>
-        <location filename="../EventEditDialog.ui" line="142"/>
+        <location filename="../EventEditDialog.ui" line="149"/>
         <source>Description</source>
         <translation>Beschrijving</translation>
     </message>
     <message>
-        <location filename="../EventEditDialog.cpp" line="28"/>
+        <location filename="../EventEditDialog.cpp" line="30"/>
         <source>Edit event</source>
         <translation>Gebeurtenis bewerken</translation>
     </message>
     <message>
-        <location filename="../EventEditDialog.cpp" line="31"/>
+        <location filename="../EventEditDialog.cpp" line="33"/>
         <source>New event</source>
         <translation>Nieuwe gebeurtenis</translation>
     </message>
@@ -548,32 +576,32 @@ day</source>
         <translation>Alarm</translation>
     </message>
     <message>
-        <location filename="../EventWindow.ui" line="179"/>
+        <location filename="../EventWindow.ui" line="182"/>
         <source>Previous event</source>
         <translation>Vorige gebeurtenis</translation>
     </message>
     <message>
-        <location filename="../EventWindow.ui" line="184"/>
+        <location filename="../EventWindow.ui" line="187"/>
         <source>Next event</source>
         <translation>Volgende gebeurtenis</translation>
     </message>
     <message>
-        <location filename="../EventWindow.ui" line="189"/>
+        <location filename="../EventWindow.ui" line="192"/>
         <source>Edit event</source>
         <translation>Gebeurtenis bewerken</translation>
     </message>
     <message>
-        <location filename="../EventWindow.ui" line="194"/>
+        <location filename="../EventWindow.ui" line="197"/>
         <source>Delete event</source>
         <translation>Gebeurtenis verwijderen</translation>
     </message>
     <message>
-        <location filename="../EventWindow.ui" line="199"/>
+        <location filename="../EventWindow.ui" line="202"/>
         <source>Clone event</source>
         <translation>Gebeurtenis kopiëren</translation>
     </message>
     <message>
-        <location filename="../EventWindow.ui" line="204"/>
+        <location filename="../EventWindow.ui" line="207"/>
         <source>Automatic links</source>
         <translation>Automatische verwijzingen</translation>
     </message>
@@ -594,17 +622,17 @@ day</source>
         <translation>Geen gebeurtenissen meer</translation>
     </message>
     <message>
-        <location filename="../EventWindow.cpp" line="269"/>
+        <location filename="../EventWindow.cpp" line="268"/>
         <source>Edit</source>
         <translation>Bewerken</translation>
     </message>
     <message>
-        <location filename="../EventWindow.cpp" line="270"/>
+        <location filename="../EventWindow.cpp" line="269"/>
         <source>Clone</source>
         <translation>Kloon</translation>
     </message>
     <message>
-        <location filename="../EventWindow.cpp" line="271"/>
+        <location filename="../EventWindow.cpp" line="270"/>
         <source>Delete</source>
         <translation>Verwijder</translation>
     </message>
@@ -698,17 +726,17 @@ day</source>
         <translation>Notities</translation>
     </message>
     <message>
-        <location filename="../JournalsPlug.cpp" line="125"/>
+        <location filename="../JournalsPlug.cpp" line="124"/>
         <source>Edit</source>
         <translation>Bewerken</translation>
     </message>
     <message>
-        <location filename="../JournalsPlug.cpp" line="126"/>
+        <location filename="../JournalsPlug.cpp" line="125"/>
         <source>Clone</source>
         <translation>Kloon</translation>
     </message>
     <message>
-        <location filename="../JournalsPlug.cpp" line="127"/>
+        <location filename="../JournalsPlug.cpp" line="126"/>
         <source>Delete</source>
         <translation>Verwijderen</translation>
     </message>
@@ -784,16 +812,6 @@ day</source>
 </context>
 <context>
     <name>QObject</name>
-    <message>
-        <location filename="../ChangeManager.cpp" line="180"/>
-        <source>Unable to edit birthdays</source>
-        <translation>Niet mogelijk geboortedatum te wijzigen</translation>
-    </message>
-    <message>
-        <location filename="../ChangeManager.cpp" line="195"/>
-        <source>Delete component?</source>
-        <translation>Onderdeel verwijderen?</translation>
-    </message>
     <message>
         <location filename="../CWrapper.h" line="59"/>
         <source>Private</source>
@@ -813,62 +831,62 @@ day</source>
         <translation>Herhaling</translation>
     </message>
     <message>
-        <location filename="../recurrence/RecurrencePickDialog.ui" line="27"/>
+        <location filename="../recurrence/RecurrencePickDialog.ui" line="24"/>
         <source>Repeat</source>
         <translation>Herhaal</translation>
     </message>
     <message>
-        <location filename="../recurrence/RecurrencePickDialog.ui" line="37"/>
+        <location filename="../recurrence/RecurrencePickDialog.ui" line="34"/>
         <source>View</source>
         <translation>Bekijk</translation>
     </message>
     <message>
-        <location filename="../recurrence/RecurrencePickDialog.ui" line="58"/>
+        <location filename="../recurrence/RecurrencePickDialog.ui" line="55"/>
         <source>Frequency</source>
         <translation>Frequentie</translation>
     </message>
     <message>
-        <location filename="../recurrence/RecurrencePickDialog.ui" line="69"/>
+        <location filename="../recurrence/RecurrencePickDialog.ui" line="66"/>
         <source>Daily</source>
         <translation>Dagelijks</translation>
     </message>
     <message>
-        <location filename="../recurrence/RecurrencePickDialog.ui" line="74"/>
+        <location filename="../recurrence/RecurrencePickDialog.ui" line="71"/>
         <source>Weekly</source>
         <translation>Wekelijks</translation>
     </message>
     <message>
-        <location filename="../recurrence/RecurrencePickDialog.ui" line="79"/>
+        <location filename="../recurrence/RecurrencePickDialog.ui" line="76"/>
         <source>Monthly</source>
         <translation>Maandelijks</translation>
     </message>
     <message>
-        <location filename="../recurrence/RecurrencePickDialog.ui" line="84"/>
+        <location filename="../recurrence/RecurrencePickDialog.ui" line="81"/>
         <source>Yearly</source>
         <translation>Jaarlijks</translation>
     </message>
     <message>
-        <location filename="../recurrence/RecurrencePickDialog.ui" line="92"/>
+        <location filename="../recurrence/RecurrencePickDialog.ui" line="89"/>
         <source>Interval</source>
         <translation>Interval</translation>
     </message>
     <message>
-        <location filename="../recurrence/RecurrencePickDialog.ui" line="116"/>
+        <location filename="../recurrence/RecurrencePickDialog.ui" line="113"/>
         <source>Forever</source>
         <translation>Voor altijd</translation>
     </message>
     <message>
-        <location filename="../recurrence/RecurrencePickDialog.ui" line="121"/>
+        <location filename="../recurrence/RecurrencePickDialog.ui" line="118"/>
         <source>Until</source>
         <translation>Tot</translation>
     </message>
     <message>
-        <location filename="../recurrence/RecurrencePickDialog.ui" line="126"/>
+        <location filename="../recurrence/RecurrencePickDialog.ui" line="123"/>
         <source>Count</source>
         <translation>Keren</translation>
     </message>
     <message>
-        <location filename="../recurrence/RecurrencePickDialog.ui" line="191"/>
+        <location filename="../recurrence/RecurrencePickDialog.ui" line="188"/>
         <source>Week start</source>
         <translation>Begin week</translation>
     </message>
@@ -960,32 +978,37 @@ day</source>
         <translation>Instellingen</translation>
     </message>
     <message>
-        <location filename="../settings/SettingsDialog.ui" line="20"/>
+        <location filename="../settings/SettingsDialog.ui" line="31"/>
         <source>Edit calendars</source>
         <translation>Kalender bewerken</translation>
     </message>
     <message>
-        <location filename="../settings/SettingsDialog.ui" line="30"/>
+        <location filename="../settings/SettingsDialog.ui" line="41"/>
         <source>Alarm tone</source>
         <translation>Alarm signaal</translation>
     </message>
     <message>
-        <location filename="../settings/SettingsDialog.ui" line="40"/>
+        <location filename="../settings/SettingsDialog.ui" line="51"/>
         <source>Delete events</source>
         <translation>Verwijder gebeurtenissen</translation>
     </message>
     <message>
-        <location filename="../settings/SettingsDialog.ui" line="50"/>
+        <location filename="../settings/SettingsDialog.ui" line="61"/>
         <source>Delete tasks</source>
         <translation>Verwijderen taken</translation>
     </message>
     <message>
-        <location filename="../settings/SettingsDialog.ui" line="60"/>
+        <location filename="../settings/SettingsDialog.ui" line="71"/>
         <source>First day of week</source>
         <translation>Eerste dag van de week</translation>
     </message>
     <message>
-        <location filename="../settings/SettingsDialog.ui" line="70"/>
+        <location filename="../settings/SettingsDialog.ui" line="81"/>
+        <source>Editable time zones</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settings/SettingsDialog.ui" line="88"/>
         <source>Date formats</source>
         <translation>Datum notaties</translation>
     </message>
@@ -995,13 +1018,13 @@ day</source>
         <translation>Opslaan</translation>
     </message>
     <message>
-        <location filename="../settings/SettingsDialog.cpp" line="65"/>
+        <location filename="../settings/SettingsDialog.cpp" line="66"/>
         <source>Never</source>
         <translation>Nooit</translation>
     </message>
     <message numerus="yes">
-        <location filename="../settings/SettingsDialog.cpp" line="67"/>
-        <location filename="../settings/SettingsDialog.cpp" line="69"/>
+        <location filename="../settings/SettingsDialog.cpp" line="68"/>
+        <location filename="../settings/SettingsDialog.cpp" line="70"/>
         <source>Older than %n week(s)</source>
         <translation>
             <numerusform>Ouder dan %n week</numerusform>
@@ -1009,7 +1032,7 @@ day</source>
         </translation>
     </message>
     <message numerus="yes">
-        <location filename="../settings/SettingsDialog.cpp" line="71"/>
+        <location filename="../settings/SettingsDialog.cpp" line="72"/>
         <source>Older than %n month(s)</source>
         <translation>
             <numerusform>Ouder dan %n maand</numerusform>
@@ -1017,7 +1040,7 @@ day</source>
         </translation>
     </message>
     <message numerus="yes">
-        <location filename="../settings/SettingsDialog.cpp" line="73"/>
+        <location filename="../settings/SettingsDialog.cpp" line="74"/>
         <source>Older than %n year(s)</source>
         <translation>
             <numerusform>Ouder dan %n jaar</numerusform>
@@ -1039,16 +1062,21 @@ day</source>
     </message>
     <message>
         <location filename="../TodoEditDialog.ui" line="42"/>
+        <source>Time zone</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../TodoEditDialog.ui" line="49"/>
         <source>Calendar</source>
         <translation>Kalender</translation>
     </message>
     <message>
-        <location filename="../TodoEditDialog.ui" line="49"/>
+        <location filename="../TodoEditDialog.ui" line="56"/>
         <source>Alarm</source>
         <translation>Alarm</translation>
     </message>
     <message>
-        <location filename="../TodoEditDialog.ui" line="56"/>
+        <location filename="../TodoEditDialog.ui" line="63"/>
         <source>Description</source>
         <translation>Beschrijving</translation>
     </message>
@@ -1106,17 +1134,17 @@ day</source>
         <translation>Automatische verwijzingen</translation>
     </message>
     <message>
-        <location filename="../TodoWindow.cpp" line="172"/>
+        <location filename="../TodoWindow.cpp" line="171"/>
         <source>Edit</source>
         <translation>Bewerken</translation>
     </message>
     <message>
-        <location filename="../TodoWindow.cpp" line="173"/>
+        <location filename="../TodoWindow.cpp" line="172"/>
         <source>Clone</source>
         <translation>Kloon</translation>
     </message>
     <message>
-        <location filename="../TodoWindow.cpp" line="174"/>
+        <location filename="../TodoWindow.cpp" line="173"/>
         <source>Delete</source>
         <translation>Verwijder</translation>
     </message>
@@ -1125,6 +1153,7 @@ day</source>
     <name>TodosPlug</name>
     <message>
         <location filename="../TodosPlug.cpp" line="34"/>
+        <location filename="../TodosPlug.cpp" line="329"/>
         <source>New task</source>
         <translation>Nieuwe taak</translation>
     </message>
@@ -1135,31 +1164,36 @@ day</source>
     </message>
     <message>
         <location filename="../TodosPlug.cpp" line="42"/>
+        <source>Group by calendar</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../TodosPlug.cpp" line="43"/>
         <source>Delete completed</source>
         <translation>Verwijder afgerond</translation>
     </message>
     <message>
-        <location filename="../TodosPlug.cpp" line="79"/>
+        <location filename="../TodosPlug.cpp" line="71"/>
         <source>Tasks</source>
         <translation>Taken</translation>
     </message>
     <message>
-        <location filename="../TodosPlug.cpp" line="203"/>
+        <location filename="../TodosPlug.cpp" line="332"/>
         <source>Edit</source>
         <translation>Bewerken</translation>
     </message>
     <message>
-        <location filename="../TodosPlug.cpp" line="204"/>
+        <location filename="../TodosPlug.cpp" line="333"/>
         <source>Clone</source>
         <translation>Kloon</translation>
     </message>
     <message>
-        <location filename="../TodosPlug.cpp" line="205"/>
+        <location filename="../TodosPlug.cpp" line="334"/>
         <source>Delete</source>
         <translation>Verwijderen</translation>
     </message>
     <message>
-        <location filename="../TodosPlug.cpp" line="235"/>
+        <location filename="../TodosPlug.cpp" line="379"/>
         <source>Delete completed tasks from all calendars?</source>
         <translation>Afgeronde taken van alle kalenders verwijderen?</translation>
     </message>
@@ -1236,4 +1270,22 @@ day</source>
         <translation>Hele dag</translation>
     </message>
 </context>
+<context>
+    <name>ZonePickDialog</name>
+    <message>
+        <location filename="../ZonePickDialog.ui" line="6"/>
+        <source>Time zone</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ZonePickDialog.ui" line="39"/>
+        <source>Search</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ZonePickDialog.cpp" line="79"/>
+        <source>Current</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 </TS>
